@@ -419,8 +419,9 @@ static int modify_pm_count(struct config *config, char *user,
 
 	argv = arglist_build(config->command[CMD_PMVARRUN], vinfo);
 	memset(&proc, 0, sizeof(proc));
+	proc.p_flags = HXPROC_STDOUT;
 	if (config->debug)
-		proc.p_flags = HXPROC_VERBOSE | HXPROC_STDOUT;
+		proc.p_flags |= HXPROC_VERBOSE;
 	proc.p_ops   = &pmt_dropprivs_ops;
 	if ((ret = pmt_spawn_dq(argv, &proc)) <= 0) {
 		l0g("error executing pmvarrun: %s\n", strerror(-ret));
